@@ -1,7 +1,7 @@
 import pandas as pd
 
 
-def mfi(df, high="high", low="low", close="close", volume="volume", col="mfi", n):
+def mfi(df, n, high="high", low="low", close="close", volume="volume", col="mfi"):
     """
     The Money Flow Index (MFI) is an oscillator that uses both price and volume to measure buying and selling pressure.
     Money flow is positive when the typical price rises (buying pressure) and negative when the typical price declines (selling pressure). 
