@@ -6,7 +6,7 @@ from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
 
-def ppo(df, price="close", col="ppo", fast_period, slow_period, ma_type):
+def ppo(df, fast_period, slow_period, ma_type, price="close", col="ppo"):
     """
     The Percentage Price Oscillator (PPO) is a momentum oscillator that measures
     the difference between two moving averages as a percentage of the larger
