@@ -1,7 +1,7 @@
 import pandas as pd
 
 
-def rocr(df, price="close", col="rocr", n):
+def rocr(df, n, price="close", col="rocr"):
     """
     The Rate-of-Change Ratio (ROCR) indicator, which is also referred to as simply
     Momentum, is a pure momentum oscillator that measures the percent change in
