@@ -1,7 +1,7 @@
 import pandas as pd
 
 
-def willr(df, high="high", low="low", close="close", col="willr", n):
+def willr(df,n, high="high", low="low", close="close", col="willr"):
     """
     The Williams %R is a momentum indicator, which gauges if a stock is overbought or oversold.
 
