@@ -1,4 +1,4 @@
-def ohlcv(df,col,n):
+def ohlcv(df,col,n=1):
 
 	df = df.copy()
 	df = df[['datetime',col]]
