@@ -2,7 +2,7 @@ import pandas as pd
 from voyant_indicators.trend.aroon import aroon
 
 
-def aroonosc(df, high="high", low="low", col="aroonosc", n):
+def aroonosc(df, n, high="high", low="low", col="aroonosc"):
     """
     An Aroon Oscillator is a trend-following indicator that uses aspects of the
     Aroon Indicator ("Aroon Up" and "Aroon Down") to gauge the strength of a
