@@ -8,7 +8,7 @@ from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
 
-def cci(df, high="high", low="low", close="close", col="cci", n, c=0.015):
+def cci(df, n, high="high", low="low", close="close", col="cci", c=0.015):
     """
     The CCI is designed to detect beginning and ending market trends. The range
     of 100 to -100 is the normal trading range. CCI values outside of this range
