@@ -1,4 +1,4 @@
-def de_marker(df,high, low col, period=14):
+def de_marker(df,high="high", low="low", col="demarker", period=14):
         """
         DeMarker (DeM)
         --------------
