@@ -8,7 +8,7 @@ from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
 
-def trima(df, price, col="trima", n):
+def trima(df, price,n, col="trima"):
     """
     The Triangular Moving Average (TRIMA) is similar to other moving averages in
     that it shows the average (or mean) price over a specified number of data
