@@ -10,7 +10,7 @@ from voyant_indicators.overlapping_studies.tema import tema
 from voyant_indicators.momentum.roc import roc
 
 
-def trix(df, price="close", col="trix", n):
+def trix(df, n, price="close", col="trix"):
     """
     TRIX is a momentum oscillator that displays the percent rate of change of a
     triple exponentially smoothed moving average.
