@@ -8,7 +8,7 @@ from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
 
-def upper_bbands(df, price="close", col="bbands", n_bdev=2, ma_type, n):
+def upper_bbands(df, ma_type, n, price="close", col="bbands", n_bdev=2):
     """
     Bollinger Bands are volatility bands placed above and below a moving average.
     Volatility is based on the standard deviation, which changes as volatility
